@@ -1,14 +1,15 @@
 package DBIx::Skinny::DBD;
 use strict;
 use warnings;
+use Carp ();
 
 sub new {
     my ($class, $dbd_type) =@_;
-    die "No Driver" unless $dbd_type;
+    Carp::confess "No Driver" unless $dbd_type;
 
     my $subclass = join '::', $class, $dbd_type;
     eval "use $subclass"; ## no critic
-    die $@ if $@;
+    Carp::confess $@ if $@;
     bless {}, $subclass;
 }
 
